@@ -30,7 +30,7 @@
 using namespace Analitza;
 
 PlotsView3D::PlotsView3D(QWidget *parent)
-    : QGLWidget(parent), m_selection(0)
+    : QGLWidget(parent), m_selection(0), old_x(-1), old_y(-1)
 {
     setFocusPolicy(Qt::ClickFocus);
 }
@@ -136,9 +136,9 @@ void PlotsView3D::modelChanged()
 //         }
 //     }
 
-    connect(model(), SIGNAL(dataChanged(QModelIndex,QModelIndex)), this, SLOT(updateFuncs(QModelIndex,QModelIndex)));
-    connect(model(), SIGNAL(rowsInserted(QModelIndex,int,int)), this, SLOT(addFuncs(QModelIndex,int,int)));
-    connect(model(), SIGNAL(rowsRemoved(QModelIndex,int,int)), this, SLOT(removeFuncs(QModelIndex,int,int)));
+    connect(model(), &QAbstractItemModel::dataChanged, this, &PlotsView3D::updateFuncs);
+    connect(model(), &QAbstractItemModel::rowsInserted, this, &PlotsView3D::addFuncs);
+    connect(model(), &QAbstractItemModel::rowsRemoved, this, &PlotsView3D::removeFuncs);
 
     update();
 }
